@@ -1,7 +1,6 @@
 
 package java.lang;
 
-import com.ibm.oti.vm.J9UnmodifiableClass;
 import java.lang.ref.SoftReference;
 import java.lang.reflect.*;
 import java.security.AccessController;
@@ -25,7 +24,7 @@ import jdk.internal.misc.Unsafe;
 import com.ibm.oti.util.Msg;
 
 /*******************************************************************************
- * Copyright (c) 1998, 2019 IBM Corp. and others
+ * Copyright (c) 1998, 2018 IBM Corp. and others
  *
  * This program and the accompanying materials are made available under
  * the terms of the Eclipse Public License 2.0 which accompanies this
@@ -46,7 +45,6 @@ import com.ibm.oti.util.Msg;
  * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0 WITH Classpath-exception-2.0 OR LicenseRef-GPL-2.0 WITH Assembly-exception
  *******************************************************************************/
 
-@J9UnmodifiableClass
 final class J9VMInternals {
 	
 	private static final int j9Version = 0x06040270;
